<?php
namespace Ak\Woo\Sandbox;

use Ak\Wp\Service\ConfigFactory;
use Ak\Wp\Service\ContainerFactory;
use Ak\Wp\WordPress;
use AkTest\Woo\TestConfigProvider;
use Zend\Diactoros\Response;
use Zend\Diactoros\ServerRequest;
use Zend\Diactoros\ServerRequestFactory;
use Zend\HttpHandlerRunner\Emitter\SapiEmitter;
use Zend\HttpHandlerRunner\RequestHandlerRunner;
use Zend\Stratigility\Middleware\ErrorResponseGenerator;

include __DIR__ . '/vendor/autoload.php';

$GLOBALS['wc_cpdf'] = null;

$configFactory = new ConfigFactory(__DIR__ . '/var/config', [
    \Ak\Woo\ConfigProvider::class,
    TestConfigProvider::class,
]);
$config = $configFactory(__DIR__ . '/config', true);

$containerFactory = new ContainerFactory();
$container = $containerFactory($config);

define('ABSPATH', __DIR__ . '/wp/');

wp_paths();
wp_db_config($container);
wp_debug_config($container);

$app = new WordPress($container);

$runner = new RequestHandlerRunner(
    $app,
    new SapiEmitter(),
    function () use ($container) {
        return ServerRequestFactory::fromGlobals()
            ->withAttribute('container', $container);
    },
    function (\Throwable $e) {
        $generator = new ErrorResponseGenerator();
        return $generator($e, new ServerRequest(), new Response());
    }
);

$runner->run();